/*
 * LearningToolView.java
 */
package learningtool;

import java.awt.Color;
import org.jdesktop.application.Action;
import org.jdesktop.application.ResourceMap;
import org.jdesktop.application.SingleFrameApplication;
import org.jdesktop.application.FrameView;
import org.jdesktop.application.TaskMonitor;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.ButtonModel;
import javax.swing.Timer;
import javax.swing.Icon;
import javax.swing.JDialog;
import javax.swing.JFrame;
import javax.swing.table.TableCellRenderer;

/**
 * The application's main frame.
 */
public class LearningToolView extends FrameView {

    public LearningToolView(SingleFrameApplication app) {
        super(app);

        initComponents();

        // status bar initialization - message timeout, idle icon and busy animation, etc
        ResourceMap resourceMap = getResourceMap();
        int messageTimeout = resourceMap.getInteger("StatusBar.messageTimeout");
        messageTimer = new Timer(messageTimeout, new ActionListener() {

            public void actionPerformed(ActionEvent e) {
                statusMessageLabel.setText("");
            }
        });
        messageTimer.setRepeats(false);
        int busyAnimationRate = resourceMap.getInteger("StatusBar.busyAnimationRate");
        for (int i = 0; i < busyIcons.length; i++) {
            busyIcons[i] = resourceMap.getIcon("StatusBar.busyIcons[" + i + "]");
        }
        busyIconTimer = new Timer(busyAnimationRate, new ActionListener() {

            public void actionPerformed(ActionEvent e) {
                busyIconIndex = (busyIconIndex + 1) % busyIcons.length;
                statusAnimationLabel.setIcon(busyIcons[busyIconIndex]);
            }
        });
        idleIcon = resourceMap.getIcon("StatusBar.idleIcon");
        statusAnimationLabel.setIcon(idleIcon);
        progressBar.setVisible(false);

        // connecting action tasks to status bar via TaskMonitor
        TaskMonitor taskMonitor = new TaskMonitor(getApplication().getContext());
        taskMonitor.addPropertyChangeListener(new java.beans.PropertyChangeListener() {

            public void propertyChange(java.beans.PropertyChangeEvent evt) {
                String propertyName = evt.getPropertyName();
                if ("started".equals(propertyName)) {
                    if (!busyIconTimer.isRunning()) {
                        statusAnimationLabel.setIcon(busyIcons[0]);
                        busyIconIndex = 0;
                        busyIconTimer.start();
                    }
                    progressBar.setVisible(true);
                    progressBar.setIndeterminate(true);
                } else if ("done".equals(propertyName)) {
                    busyIconTimer.stop();
                    statusAnimationLabel.setIcon(idleIcon);
                    progressBar.setVisible(false);
                    progressBar.setValue(0);
                } else if ("message".equals(propertyName)) {
                    String text = (String) (evt.getNewValue());
                    statusMessageLabel.setText((text == null) ? "" : text);
                    messageTimer.restart();
                } else if ("progress".equals(propertyName)) {
                    int value = (Integer) (evt.getNewValue());
                    progressBar.setVisible(true);
                    progressBar.setIndeterminate(false);
                    progressBar.setValue(value);
                }
            }
        });
    }

    @Action
    public void showAboutBox() {
        if (aboutBox == null) {
            JFrame mainFrame = LearningToolApp.getApplication().getMainFrame();
            aboutBox = new LearningToolAboutBox(mainFrame);
            aboutBox.setLocationRelativeTo(mainFrame);
        }
        LearningToolApp.getApplication().show(aboutBox);
    }

    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        mainPanel = new javax.swing.JPanel();
        jSplitPane1 = new javax.swing.JSplitPane();
        jPanel1 = new javax.swing.JPanel();
        jPanel2 = new javax.swing.JPanel();
        jLabel2 = new javax.swing.JLabel();
        jLabel3 = new javax.swing.JLabel();
        jLabel4 = new javax.swing.JLabel();
        MM_Combo = new javax.swing.JComboBox();
        PS_Combo = new javax.swing.JComboBox();
        TLB_Combo = new javax.swing.JComboBox();
        jLabel1 = new javax.swing.JLabel();
        VM_Combo = new javax.swing.JComboBox();
        jPanel3 = new javax.swing.JPanel();
        Fifo = new javax.swing.JRadioButton();
        Lifo = new javax.swing.JRadioButton();
        Lru = new javax.swing.JRadioButton();
        More = new javax.swing.JRadioButton();
        Extra_Policy = new javax.swing.JComboBox();
        jPanel4 = new javax.swing.JPanel();
        One_level = new javax.swing.JRadioButton();
        Two_Level = new javax.swing.JRadioButton();
        Submit = new javax.swing.JButton();
        jPanel5 = new javax.swing.JPanel();
        jSplitPane2 = new javax.swing.JSplitPane();
        jPanel6 = new javax.swing.JPanel();
        jPanel8 = new javax.swing.JPanel();
        Restart = new javax.swing.JButton();
        Generate_VA = new javax.swing.JButton();
        Generate_VPN = new javax.swing.JButton();
        VA_Generate = new javax.swing.JTextField();
        VPN_Box = new javax.swing.JTextField();
        Map_VA = new javax.swing.JButton();
        Map_VPN = new javax.swing.JButton();
        jRadioButton7 = new javax.swing.JRadioButton();
        jRadioButton8 = new javax.swing.JRadioButton();
        jLabel5 = new javax.swing.JLabel();
        jLabel6 = new javax.swing.JLabel();
        jLabel7 = new javax.swing.JLabel();
        jLabel8 = new javax.swing.JLabel();
        NumMiss = new javax.swing.JLabel();
        NumHit = new javax.swing.JLabel();
        jSplitPane3 = new javax.swing.JSplitPane();
        jPanel11 = new javax.swing.JPanel();
        jScrollPane11 = new javax.swing.JScrollPane();
        AddressDetail2 = new javax.swing.JTable();
        jPanel12 = new javax.swing.JPanel();
        jScrollPane10 = new javax.swing.JScrollPane();
        AddressDetail1 = new javax.swing.JTable();
        jTabbedPane1 = new javax.swing.JTabbedPane();
        jPanel9 = new javax.swing.JPanel();
        jScrollPane5 = new javax.swing.JScrollPane();
        MM_Table = new javax.swing.JTable();
        jScrollPane2 = new javax.swing.JScrollPane();
        VM_Table = new javax.swing.JTable();
        jSplitPane4 = new javax.swing.JSplitPane();
        jPanel13 = new javax.swing.JPanel();
        jScrollPane3 = new javax.swing.JScrollPane();
        Level1 = new javax.swing.JTable();
        jPanel14 = new javax.swing.JPanel();
        jScrollPane4 = new javax.swing.JScrollPane();
        Level2 = new javax.swing.JTable();
        jScrollPane8 = new javax.swing.JScrollPane();
        Explaination = new javax.swing.JTextArea();
        jPanel10 = new javax.swing.JPanel();
        jLabel11 = new javax.swing.JLabel();
        Next_victim = new javax.swing.JLabel();
        jScrollPane9 = new javax.swing.JScrollPane();
        HoodTable = new javax.swing.JTable();
        jPanel7 = new javax.swing.JPanel();
        jScrollPane6 = new javax.swing.JScrollPane();
        summary_2 = new javax.swing.JTable();
        jScrollPane7 = new javax.swing.JScrollPane();
        summary = new javax.swing.JTable();
        jScrollPane1 = new javax.swing.JScrollPane();
        HistoryBox = new javax.swing.JTextArea();
        menuBar = new javax.swing.JMenuBar();
        javax.swing.JMenu fileMenu = new javax.swing.JMenu();
        javax.swing.JMenuItem exitMenuItem = new javax.swing.JMenuItem();
        javax.swing.JMenu helpMenu = new javax.swing.JMenu();
        javax.swing.JMenuItem aboutMenuItem = new javax.swing.JMenuItem();
        statusPanel = new javax.swing.JPanel();
        javax.swing.JSeparator statusPanelSeparator = new javax.swing.JSeparator();
        statusMessageLabel = new javax.swing.JLabel();
        statusAnimationLabel = new javax.swing.JLabel();
        progressBar = new javax.swing.JProgressBar();
        buttonGroup1 = new javax.swing.ButtonGroup();
        buttonGroup2 = new javax.swing.ButtonGroup();
        buttonGroup3 = new javax.swing.ButtonGroup();

        org.jdesktop.application.ResourceMap resourceMap = org.jdesktop.application.Application.getInstance(learningtool.LearningToolApp.class).getContext().getResourceMap(LearningToolView.class);
        mainPanel.setBackground(resourceMap.getColor("mainPanel.background")); // NOI18N
        mainPanel.setName("mainPanel"); // NOI18N

        jSplitPane1.setDividerLocation(200);
        jSplitPane1.setName("jSplitPane1"); // NOI18N

        jPanel1.setBackground(resourceMap.getColor("jPanel1.background")); // NOI18N
        jPanel1.setName("jPanel1"); // NOI18N

        jPanel2.setBorder(javax.swing.BorderFactory.createTitledBorder(new javax.swing.border.LineBorder(new java.awt.Color(0, 0, 0), 1, true), resourceMap.getString("jPanel2.border.title"))); // NOI18N
        jPanel2.setName("jPanel2"); // NOI18N

        jLabel2.setText(resourceMap.getString("jLabel2.text")); // NOI18N
        jLabel2.setName("jLabel2"); // NOI18N

        jLabel3.setText(resourceMap.getString("jLabel3.text")); // NOI18N
        jLabel3.setName("jLabel3"); // NOI18N

        jLabel4.setText(resourceMap.getString("jLabel4.text")); // NOI18N
        jLabel4.setName("jLabel4"); // NOI18N

        MM_Combo.setModel(new javax.swing.DefaultComboBoxModel(new String[] { "4 KB", "8 KB", "12 KB", "16 KB", "20 KB", "24 KB", "28 KB", "32 KB", "36 KB", "40 KB", "44 KB", "48 KB", "52 KB", "56 KB", "60 KB", "64 KB" }));
        MM_Combo.setSelectedIndex(3);
        MM_Combo.setName("MM_Combo"); // NOI18N

        PS_Combo.setModel(new javax.swing.DefaultComboBoxModel(new String[] { "2 KB", "4 KB", "8 KB" }));
        PS_Combo.setSelectedIndex(1);
        PS_Combo.setName("PS_Combo"); // NOI18N
        PS_Combo.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                PS_ComboActionPerformed(evt);
            }
        });

        TLB_Combo.setModel(new javax.swing.DefaultComboBoxModel(new String[] { "Item 1", "Item 2", "Item 3", "Item 4" }));
        TLB_Combo.setName("TLB_Combo"); // NOI18N

        jLabel1.setText(resourceMap.getString("jLabel1.text")); // NOI18N
        jLabel1.setName("jLabel1"); // NOI18N

        VM_Combo.setModel(new javax.swing.DefaultComboBoxModel(new String[] { "4 KB", "8 KB", "12 KB", "16 KB", "20 KB", "24 KB", "28 KB", "32 KB", "36 KB", "40 KB", "44 KB", "48 KB", "52 KB", "56 KB", "60 KB", "64 KB" }));
        VM_Combo.setSelectedIndex(7);
        VM_Combo.setName("VM_Combo"); // NOI18N

        javax.swing.GroupLayout jPanel2Layout = new javax.swing.GroupLayout(jPanel2);
        jPanel2.setLayout(jPanel2Layout);
        jPanel2Layout.setHorizontalGroup(
            jPanel2Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel2Layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(jPanel2Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(jPanel2Layout.createSequentialGroup()
                        .addGroup(jPanel2Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                            .addComponent(jLabel2)
                            .addComponent(jLabel3)
                            .addComponent(jLabel4))
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, 30, Short.MAX_VALUE)
                        .addGroup(jPanel2Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING, false)
                            .addComponent(VM_Combo, 0, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                            .addComponent(TLB_Combo, 0, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                            .addComponent(MM_Combo, 0, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                            .addComponent(PS_Combo, 0, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
                        .addContainerGap())
                    .addComponent(jLabel1)))
        );
        jPanel2Layout.setVerticalGroup(
            jPanel2Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel2Layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(jPanel2Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(jLabel3)
                    .addComponent(PS_Combo, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                .addGroup(jPanel2Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(jLabel2)
                    .addComponent(MM_Combo, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addGap(17, 17, 17)
                .addGroup(jPanel2Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(jLabel1)
                    .addComponent(VM_Combo, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                .addGroup(jPanel2Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(TLB_Combo, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(jLabel4))
                .addContainerGap(15, Short.MAX_VALUE))
        );

        jPanel3.setBorder(javax.swing.BorderFactory.createTitledBorder(new javax.swing.border.LineBorder(new java.awt.Color(0, 0, 0), 1, true), resourceMap.getString("jPanel3.border.title"))); // NOI18N
        jPanel3.setName("jPanel3"); // NOI18N

        buttonGroup1.add(Fifo);
        Fifo.setSelected(true);
        Fifo.setText(resourceMap.getString("Fifo.text")); // NOI18N
        Fifo.setActionCommand(resourceMap.getString("Fifo.ActionCommand")); // NOI18N
        Fifo.setName("Fifo"); // NOI18N

        buttonGroup1.add(Lifo);
        Lifo.setText(resourceMap.getString("Lifo.text")); // NOI18N
        Lifo.setActionCommand(resourceMap.getString("Lifo.ActionCommand")); // NOI18N
        Lifo.setName("Lifo"); // NOI18N

        buttonGroup1.add(Lru);
        Lru.setText(resourceMap.getString("Lru.text")); // NOI18N
        Lru.setActionCommand(resourceMap.getString("Lru.ActionCommand")); // NOI18N
        Lru.setName("Lru"); // NOI18N

        buttonGroup1.add(More);
        More.setText(resourceMap.getString("More.text")); // NOI18N
        More.setActionCommand(resourceMap.getString("More.ActionCommand")); // NOI18N
        More.setName("More"); // NOI18N
        More.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                MoreActionPerformed(evt);
            }
        });

        Extra_Policy.setModel(new javax.swing.DefaultComboBoxModel(new String[] { "Item 1", "Item 2", "Item 3", "Item 4" }));
        Extra_Policy.setName("Extra_Policy"); // NOI18N
        Extra_Policy.setVisible(false);

        javax.swing.GroupLayout jPanel3Layout = new javax.swing.GroupLayout(jPanel3);
        jPanel3.setLayout(jPanel3Layout);
        jPanel3Layout.setHorizontalGroup(
            jPanel3Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel3Layout.createSequentialGroup()
                .addGroup(jPanel3Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(jPanel3Layout.createSequentialGroup()
                        .addContainerGap()
                        .addGroup(jPanel3Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING, false)
                            .addComponent(More, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                            .addComponent(Lru, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                            .addComponent(Lifo, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                            .addComponent(Fifo, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)))
                    .addGroup(jPanel3Layout.createSequentialGroup()
                        .addGap(46, 46, 46)
                        .addComponent(Extra_Policy, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)))
                .addContainerGap(67, Short.MAX_VALUE))
        );
        jPanel3Layout.setVerticalGroup(
            jPanel3Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel3Layout.createSequentialGroup()
                .addContainerGap()
                .addComponent(Fifo)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                .addComponent(Lifo)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                .addComponent(Lru)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                .addComponent(More)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(Extra_Policy, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addContainerGap(14, Short.MAX_VALUE))
        );

        jPanel4.setBorder(javax.swing.BorderFactory.createTitledBorder(new javax.swing.border.LineBorder(new java.awt.Color(0, 0, 0), 1, true), resourceMap.getString("jPanel4.border.title"))); // NOI18N
        jPanel4.setName("jPanel4"); // NOI18N

        buttonGroup2.add(One_level);
        One_level.setSelected(true);
        One_level.setText(resourceMap.getString("One_level.text")); // NOI18N
        One_level.setActionCommand(resourceMap.getString("One_level.ActionCommand")); // NOI18N
        One_level.setName("One_level"); // NOI18N

        buttonGroup2.add(Two_Level);
        Two_Level.setText(resourceMap.getString("Two_Level.text")); // NOI18N
        Two_Level.setActionCommand(resourceMap.getString("Two_Level.ActionCommand")); // NOI18N
        Two_Level.setName("Two_Level"); // NOI18N

        javax.swing.GroupLayout jPanel4Layout = new javax.swing.GroupLayout(jPanel4);
        jPanel4.setLayout(jPanel4Layout);
        jPanel4Layout.setHorizontalGroup(
            jPanel4Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel4Layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(jPanel4Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(One_level)
                    .addComponent(Two_Level))
                .addContainerGap(82, Short.MAX_VALUE))
        );
        jPanel4Layout.setVerticalGroup(
            jPanel4Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel4Layout.createSequentialGroup()
                .addContainerGap()
                .addComponent(One_level)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(Two_Level)
                .addContainerGap(17, Short.MAX_VALUE))
        );

        Submit.setText(resourceMap.getString("Submit.text")); // NOI18N
        Submit.setCursor(new java.awt.Cursor(java.awt.Cursor.HAND_CURSOR));
        Submit.setName("Submit"); // NOI18N
        Submit.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                SubmitActionPerformed(evt);
            }
        });

        javax.swing.GroupLayout jPanel1Layout = new javax.swing.GroupLayout(jPanel1);
        jPanel1.setLayout(jPanel1Layout);
        jPanel1Layout.setHorizontalGroup(
            jPanel1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel1Layout.createSequentialGroup()
                .addGroup(jPanel1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(jPanel1Layout.createSequentialGroup()
                        .addContainerGap()
                        .addComponent(jPanel4, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
                    .addGroup(jPanel1Layout.createSequentialGroup()
                        .addContainerGap()
                        .addComponent(jPanel3, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
                    .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, jPanel1Layout.createSequentialGroup()
                        .addContainerGap()
                        .addComponent(jPanel2, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
                    .addGroup(jPanel1Layout.createSequentialGroup()
                        .addGap(51, 51, 51)
                        .addComponent(Submit)))
                .addContainerGap())
        );
        jPanel1Layout.setVerticalGroup(
            jPanel1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel1Layout.createSequentialGroup()
                .addGap(35, 35, 35)
                .addComponent(jPanel2, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                .addComponent(jPanel3, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                .addComponent(jPanel4, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addGap(39, 39, 39)
                .addComponent(Submit)
                .addContainerGap(87, Short.MAX_VALUE))
        );

        jSplitPane1.setLeftComponent(jPanel1);

        jPanel5.setName("jPanel5"); // NOI18N

        jSplitPane2.setDividerLocation(740);
        jSplitPane2.setResizeWeight(1.0);
        jSplitPane2.setName("jSplitPane2"); // NOI18N

        jPanel6.setBackground(resourceMap.getColor("jPanel6.background")); // NOI18N
        jPanel6.setName("jPanel6"); // NOI18N

        jPanel8.setBackground(resourceMap.getColor("jPanel8.background")); // NOI18N
        jPanel8.setName("jPanel8"); // NOI18N

        Restart.setText(resourceMap.getString("Restart.text")); // NOI18N
        Restart.setName("Restart"); // NOI18N
        Restart.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                RestartActionPerformed(evt);
            }
        });

        Generate_VA.setText(resourceMap.getString("Generate_VA.text")); // NOI18N
        Generate_VA.setName("Generate_VA"); // NOI18N
        Generate_VA.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                Generate_VAActionPerformed(evt);
            }
        });

        Generate_VPN.setText(resourceMap.getString("Generate_VPN.text")); // NOI18N
        Generate_VPN.setName("Generate_VPN"); // NOI18N
        Generate_VPN.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                VPN_Box_Button2(evt);
            }
        });

        VA_Generate.setForeground(resourceMap.getColor("VA_Generate.foreground")); // NOI18N
        VA_Generate.setText(resourceMap.getString("VA_Generate.text")); // NOI18N
        VA_Generate.setName("VA_Generate"); // NOI18N

        VPN_Box.setForeground(resourceMap.getColor("VPN_Box.foreground")); // NOI18N
        VPN_Box.setText(resourceMap.getString("VPN_Box.text")); // NOI18N
        VPN_Box.setName("VPN_Box"); // NOI18N

        Map_VA.setText(resourceMap.getString("Map_VA.text")); // NOI18N
        Map_VA.setName("Map_VA"); // NOI18N
        Map_VA.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                MAP_VA_button1(evt);
            }
        });

        Map_VPN.setText(resourceMap.getString("Map_VPN.text")); // NOI18N
        Map_VPN.setName("Map_VPN"); // NOI18N
        Map_VPN.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                VPN_Box_button3(evt);
            }
        });

        buttonGroup3.add(jRadioButton7);
        jRadioButton7.setSelected(true);
        jRadioButton7.setText(resourceMap.getString("jRadioButton7.text")); // NOI18N
        jRadioButton7.setActionCommand(resourceMap.getString("jRadioButton7.ActionCommand")); // NOI18N
        jRadioButton7.setName("jRadioButton7"); // NOI18N

        buttonGroup3.add(jRadioButton8);
        jRadioButton8.setText(resourceMap.getString("jRadioButton8.text")); // NOI18N
        jRadioButton8.setActionCommand(resourceMap.getString("jRadioButton8.ActionCommand")); // NOI18N
        jRadioButton8.setName("jRadioButton8"); // NOI18N

        jLabel5.setFont(resourceMap.getFont("jLabel5.font")); // NOI18N
        jLabel5.setForeground(resourceMap.getColor("jLabel6.foreground")); // NOI18N
        jLabel5.setText(resourceMap.getString("jLabel5.text")); // NOI18N
        jLabel5.setName("jLabel5"); // NOI18N

        jLabel6.setFont(resourceMap.getFont("jLabel5.font")); // NOI18N
        jLabel6.setForeground(resourceMap.getColor("jLabel6.foreground")); // NOI18N
        jLabel6.setText(resourceMap.getString("jLabel6.text")); // NOI18N
        jLabel6.setName("jLabel6"); // NOI18N

        jLabel7.setText(resourceMap.getString("jLabel7.text")); // NOI18N
        jLabel7.setName("jLabel7"); // NOI18N

        jLabel8.setText(resourceMap.getString("jLabel8.text")); // NOI18N
        jLabel8.setName("jLabel8"); // NOI18N

        NumMiss.setFont(resourceMap.getFont("jLabel5.font")); // NOI18N
        NumMiss.setForeground(resourceMap.getColor("NumMiss.foreground")); // NOI18N
        NumMiss.setText(resourceMap.getString("NumMiss.text")); // NOI18N
        NumMiss.setName("NumMiss"); // NOI18N

        NumHit.setFont(resourceMap.getFont("jLabel5.font")); // NOI18N
        NumHit.setForeground(resourceMap.getColor("jLabel9.foreground")); // NOI18N
        NumHit.setText(resourceMap.getString("NumHit.text")); // NOI18N
        NumHit.setName("NumHit"); // NOI18N

        jSplitPane3.setBackground(resourceMap.getColor("jSplitPane3.background")); // NOI18N
        jSplitPane3.setDividerLocation(1000);
        jSplitPane3.setName("jSplitPane3"); // NOI18N

        jPanel11.setBackground(resourceMap.getColor("jPanel11.background")); // NOI18N
        jPanel11.setName("jPanel11"); // NOI18N

        jScrollPane11.setName("jScrollPane11"); // NOI18N

        AddressDetail2.setModel(new javax.swing.table.DefaultTableModel(
            new Object [][] {
                {null, null, null}
            },
            new String [] {
                "OUTER", "INNER", "VPO"
            }
        ) {
            Class[] types = new Class [] {
                java.lang.String.class, java.lang.String.class, java.lang.String.class
            };

            public Class getColumnClass(int columnIndex) {
                return types [columnIndex];
            }
        });
        AddressDetail2.setName("AddressDetail2"); // NOI18N
        jScrollPane11.setViewportView(AddressDetail2);
        AddressDetail2.getColumnModel().getColumn(2).setHeaderValue(resourceMap.getString("AddressDetail2.columnModel.title2")); // NOI18N

        javax.swing.GroupLayout jPanel11Layout = new javax.swing.GroupLayout(jPanel11);
        jPanel11.setLayout(jPanel11Layout);
        jPanel11Layout.setHorizontalGroup(
            jPanel11Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel11Layout.createSequentialGroup()
                .addContainerGap()
                .addComponent(jScrollPane11, javax.swing.GroupLayout.PREFERRED_SIZE, 206, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
        );
        jPanel11Layout.setVerticalGroup(
            jPanel11Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel11Layout.createSequentialGroup()
                .addContainerGap()
                .addComponent(jScrollPane11, javax.swing.GroupLayout.DEFAULT_SIZE, 45, Short.MAX_VALUE)
                .addContainerGap())
        );

        jSplitPane3.setRightComponent(jPanel11);

        jPanel12.setBackground(resourceMap.getColor("jPanel12.background")); // NOI18N
        jPanel12.setName("jPanel12"); // NOI18N

        jScrollPane10.setName("jScrollPane10"); // NOI18N

        AddressDetail1.setModel(new javax.swing.table.DefaultTableModel(
            new Object [][] {
                {null, null}
            },
            new String [] {
                "VPN", "VPO"
            }
        ) {
            Class[] types = new Class [] {
                java.lang.String.class, java.lang.String.class
            };

            public Class getColumnClass(int columnIndex) {
                return types [columnIndex];
            }
        });
        AddressDetail1.setName("AddressDetail1"); // NOI18N
        jScrollPane10.setViewportView(AddressDetail1);
        AddressDetail1.getColumnModel().getColumn(0).setHeaderValue(resourceMap.getString("AddressDetail1.columnModel.title0")); // NOI18N
        AddressDetail1.getColumnModel().getColumn(1).setHeaderValue(resourceMap.getString("AddressDetail1.columnModel.title1")); // NOI18N

        javax.swing.GroupLayout jPanel12Layout = new javax.swing.GroupLayout(jPanel12);
        jPanel12.setLayout(jPanel12Layout);
        jPanel12Layout.setHorizontalGroup(
            jPanel12Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, jPanel12Layout.createSequentialGroup()
                .addContainerGap()
                .addComponent(jScrollPane10, javax.swing.GroupLayout.DEFAULT_SIZE, 230, Short.MAX_VALUE)
                .addContainerGap())
        );
        jPanel12Layout.setVerticalGroup(
            jPanel12Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel12Layout.createSequentialGroup()
                .addContainerGap()
                .addComponent(jScrollPane10, javax.swing.GroupLayout.PREFERRED_SIZE, 44, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addContainerGap(12, Short.MAX_VALUE))
        );

        jSplitPane3.setLeftComponent(jPanel12);

        javax.swing.GroupLayout jPanel8Layout = new javax.swing.GroupLayout(jPanel8);
        jPanel8.setLayout(jPanel8Layout);
        jPanel8Layout.setHorizontalGroup(
            jPanel8Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel8Layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(jPanel8Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(jPanel8Layout.createSequentialGroup()
                        .addComponent(Generate_VA)
                        .addGap(10, 10, 10)
                        .addComponent(VA_Generate, javax.swing.GroupLayout.PREFERRED_SIZE, 101, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(Map_VA)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, 371, Short.MAX_VALUE)
                        .addGroup(jPanel8Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                            .addComponent(jLabel7)
                            .addComponent(Restart)
                            .addComponent(jLabel8))
                        .addContainerGap())
                    .addGroup(jPanel8Layout.createSequentialGroup()
                        .addComponent(Generate_VPN)
                        .addGap(10, 10, 10)
                        .addComponent(VPN_Box, javax.swing.GroupLayout.PREFERRED_SIZE, 105, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(Map_VPN)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                        .addComponent(jSplitPane3, javax.swing.GroupLayout.PREFERRED_SIZE, 257, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addGap(72, 72, 72)
                        .addGroup(jPanel8Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                            .addGroup(jPanel8Layout.createSequentialGroup()
                                .addGap(69, 69, 69)
                                .addGroup(jPanel8Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                                    .addComponent(NumMiss)
                                    .addComponent(NumHit)))
                            .addComponent(jLabel5)
                            .addComponent(jLabel6))
                        .addGap(43, 43, 43))))
            .addGroup(jPanel8Layout.createSequentialGroup()
                .addGap(125, 125, 125)
                .addGroup(jPanel8Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING, false)
                    .addComponent(jRadioButton7, javax.swing.GroupLayout.Alignment.LEADING, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                    .addComponent(jRadioButton8, javax.swing.GroupLayout.Alignment.LEADING, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
                .addContainerGap(539, Short.MAX_VALUE))
        );
        jPanel8Layout.setVerticalGroup(
            jPanel8Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel8Layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(jPanel8Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(jPanel8Layout.createSequentialGroup()
                        .addGroup(jPanel8Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING)
                            .addGroup(jPanel8Layout.createSequentialGroup()
                                .addGroup(jPanel8Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                                    .addComponent(Restart)
                                    .addComponent(Generate_VA)
                                    .addComponent(VA_Generate, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                                    .addComponent(Map_VA))
                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, 6, Short.MAX_VALUE)
                                .addGroup(jPanel8Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                                    .addComponent(jRadioButton7)
                                    .addComponent(jLabel7))
                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                                .addGroup(jPanel8Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                                    .addComponent(jRadioButton8)
                                    .addComponent(jLabel8))
                                .addGap(10, 10, 10)
                                .addGroup(jPanel8Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                                    .addComponent(Generate_VPN)
                                    .addComponent(VPN_Box, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                                    .addComponent(Map_VPN)))
                            .addGroup(jPanel8Layout.createSequentialGroup()
                                .addGroup(jPanel8Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                                    .addComponent(jLabel5)
                                    .addComponent(NumMiss))
                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                                .addGroup(jPanel8Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                                    .addComponent(jLabel6)
                                    .addComponent(NumHit))
                                .addGap(9, 9, 9)))
                        .addGap(29, 29, 29))
                    .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, jPanel8Layout.createSequentialGroup()
                        .addComponent(jSplitPane3, javax.swing.GroupLayout.PREFERRED_SIZE, 69, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addContainerGap())))
        );

        jTabbedPane1.setName("jTabbedPane1"); // NOI18N

        jPanel9.setName("jPanel9"); // NOI18N

        jScrollPane5.setName("jScrollPane5"); // NOI18N

        MM_Table.setModel(new javax.swing.table.DefaultTableModel(
            new Object [][] {
                {null, null}
            },
            new String [] {
                "     Main Memory", "  Dirty"
            }
        ) {
            boolean[] canEdit = new boolean [] {
                true, false
            };

            public boolean isCellEditable(int rowIndex, int columnIndex) {
                return canEdit [columnIndex];
            }
        });
        MM_Table.setName("MM_Table"); // NOI18N
        jScrollPane5.setViewportView(MM_Table);
        MM_Table.getColumnModel().getColumn(0).setHeaderValue(resourceMap.getString("MM_Table.columnModel.title0")); // NOI18N
        MM_Table.getColumnModel().getColumn(1).setPreferredWidth(2);
        MM_Table.getColumnModel().getColumn(1).setHeaderValue(resourceMap.getString("MM_Table.columnModel.title1")); // NOI18N

        jScrollPane2.setName("jScrollPane2"); // NOI18N

        VM_Table.setModel(new javax.swing.table.DefaultTableModel(
            new Object [][] {
                {null}
            },
            new String [] {
                "Virtual Memory"
            }
        ));
        VM_Table.setName("VM_Table"); // NOI18N
        jScrollPane2.setViewportView(VM_Table);

        jSplitPane4.setName("jSplitPane4"); // NOI18N

        jPanel13.setName("jPanel13"); // NOI18N

        jScrollPane3.setName("jScrollPane3"); // NOI18N

        Level1.setModel(new javax.swing.table.DefaultTableModel(
            new Object [][] {
                {null, null, null},
                {null, null, null},
                {null, null, null},
                {null, null, null}
            },
            new String [] {
                "VPN", "At PPN", "Valid"
            }
        ));
        Level1.setName("Level1"); // NOI18N
        jScrollPane3.setViewportView(Level1);
        Level1.getColumnModel().getColumn(0).setHeaderValue(resourceMap.getString("jTable1.columnModel.title0")); // NOI18N
        Level1.getColumnModel().getColumn(1).setHeaderValue(resourceMap.getString("Level1.columnModel.title1")); // NOI18N
        Level1.getColumnModel().getColumn(2).setHeaderValue(resourceMap.getString("Level1.columnModel.title2")); // NOI18N

        javax.swing.GroupLayout jPanel13Layout = new javax.swing.GroupLayout(jPanel13);
        jPanel13.setLayout(jPanel13Layout);
        jPanel13Layout.setHorizontalGroup(
            jPanel13Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addComponent(jScrollPane3, javax.swing.GroupLayout.DEFAULT_SIZE, 149, Short.MAX_VALUE)
        );
        jPanel13Layout.setVerticalGroup(
            jPanel13Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addComponent(jScrollPane3, javax.swing.GroupLayout.DEFAULT_SIZE, 312, Short.MAX_VALUE)
        );

        jSplitPane4.setRightComponent(jPanel13);

        jPanel14.setName("jPanel14"); // NOI18N

        jScrollPane4.setName("jScrollPane4"); // NOI18N

        Level2.setModel(new javax.swing.table.DefaultTableModel(
            new Object [][] {
                {null},
                {null},
                {null},
                {null}
            },
            new String [] {
                "Title 1"
            }
        ));
        Level2.setName("Level2"); // NOI18N
        jScrollPane4.setViewportView(Level2);
        Level2.getColumnModel().getColumn(0).setHeaderValue(resourceMap.getString("jTable1.columnModel.title0")); // NOI18N

        javax.swing.GroupLayout jPanel14Layout = new javax.swing.GroupLayout(jPanel14);
        jPanel14.setLayout(jPanel14Layout);
        jPanel14Layout.setHorizontalGroup(
            jPanel14Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addComponent(jScrollPane4, javax.swing.GroupLayout.Alignment.TRAILING, javax.swing.GroupLayout.DEFAULT_SIZE, 100, Short.MAX_VALUE)
        );
        jPanel14Layout.setVerticalGroup(
            jPanel14Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel14Layout.createSequentialGroup()
                .addGap(90, 90, 90)
                .addComponent(jScrollPane4, javax.swing.GroupLayout.PREFERRED_SIZE, 122, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addContainerGap(100, Short.MAX_VALUE))
        );

        jSplitPane4.setLeftComponent(jPanel14);

        jScrollPane8.setName("jScrollPane8"); // NOI18N

        Explaination.setBackground(resourceMap.getColor("Explaination.background")); // NOI18N
        Explaination.setColumns(20);
        Explaination.setForeground(resourceMap.getColor("Explaination.foreground")); // NOI18N
        Explaination.setRows(5);
        Explaination.setBorder(javax.swing.BorderFactory.createTitledBorder(null, resourceMap.getString("Explaination.border.title"))); // NOI18N
        Explaination.setName("Explaination"); // NOI18N
        jScrollPane8.setViewportView(Explaination);

        javax.swing.GroupLayout jPanel9Layout = new javax.swing.GroupLayout(jPanel9);
        jPanel9.setLayout(jPanel9Layout);
        jPanel9Layout.setHorizontalGroup(
            jPanel9Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, jPanel9Layout.createSequentialGroup()
                .addGap(303, 303, 303)
                .addComponent(jScrollPane8, javax.swing.GroupLayout.DEFAULT_SIZE, 139, Short.MAX_VALUE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(jSplitPane4, javax.swing.GroupLayout.PREFERRED_SIZE, 256, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addGap(18, 18, 18))
            .addGroup(jPanel9Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                .addGroup(jPanel9Layout.createSequentialGroup()
                    .addGap(137, 137, 137)
                    .addComponent(jScrollPane5, javax.swing.GroupLayout.PREFERRED_SIZE, 152, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addContainerGap(433, Short.MAX_VALUE)))
            .addGroup(jPanel9Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                .addGroup(jPanel9Layout.createSequentialGroup()
                    .addGap(20, 20, 20)
                    .addComponent(jScrollPane2, javax.swing.GroupLayout.PREFERRED_SIZE, 99, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addContainerGap(603, Short.MAX_VALUE)))
        );
        jPanel9Layout.setVerticalGroup(
            jPanel9Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel9Layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(jPanel9Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(jScrollPane8, javax.swing.GroupLayout.Alignment.TRAILING, javax.swing.GroupLayout.DEFAULT_SIZE, 314, Short.MAX_VALUE)
                    .addComponent(jSplitPane4, javax.swing.GroupLayout.Alignment.TRAILING, javax.swing.GroupLayout.DEFAULT_SIZE, 314, Short.MAX_VALUE))
                .addGap(92, 92, 92))
            .addGroup(jPanel9Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                .addGroup(jPanel9Layout.createSequentialGroup()
                    .addContainerGap()
                    .addComponent(jScrollPane5, javax.swing.GroupLayout.PREFERRED_SIZE, 318, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addContainerGap(88, Short.MAX_VALUE)))
            .addGroup(jPanel9Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                .addGroup(jPanel9Layout.createSequentialGroup()
                    .addContainerGap()
                    .addComponent(jScrollPane2, javax.swing.GroupLayout.PREFERRED_SIZE, 318, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addContainerGap(88, Short.MAX_VALUE)))
        );

        jTabbedPane1.addTab(resourceMap.getString("jPanel9.TabConstraints.tabTitle"), jPanel9); // NOI18N

        jPanel10.setName("jPanel10"); // NOI18N

        jLabel11.setForeground(resourceMap.getColor("jLabel11.foreground")); // NOI18N
        jLabel11.setText(resourceMap.getString("jLabel11.text")); // NOI18N
        jLabel11.setName("jLabel11"); // NOI18N

        Next_victim.setForeground(resourceMap.getColor("Next_victim.foreground")); // NOI18N
        Next_victim.setText(resourceMap.getString("Next_victim.text")); // NOI18N
        Next_victim.setName("Next_victim"); // NOI18N

        jScrollPane9.setName("jScrollPane9"); // NOI18N

        HoodTable.setBackground(resourceMap.getColor("HoodTable.background")); // NOI18N
        HoodTable.setForeground(resourceMap.getColor("HoodTable.foreground")); // NOI18N
        HoodTable.setModel(new javax.swing.table.DefaultTableModel(
            new Object [][] {
                {null, null},
                {null, null},
                {null, null},
                {null, null},
                {null, null},
                {null, null},
                {null, null},
                {null, null},
                {null, null},
                {null, null},
                {null, null},
                {null, null},
                {null, null},
                {null, null},
                {null, null},
                {null, null}
            },
            new String [] {
                "            Virtual Page", "        IN TIME"
            }
        ) {
            Class[] types = new Class [] {
                java.lang.String.class, java.lang.Integer.class
            };
            boolean[] canEdit = new boolean [] {
                false, false
            };

            public Class getColumnClass(int columnIndex) {
                return types [columnIndex];
            }

            public boolean isCellEditable(int rowIndex, int columnIndex) {
                return canEdit [columnIndex];
            }
        });
        HoodTable.setName("HoodTable"); // NOI18N
        jScrollPane9.setViewportView(HoodTable);
        HoodTable.getColumnModel().getColumn(0).setHeaderValue(resourceMap.getString("HoodTable.columnModel.title0")); // NOI18N
        HoodTable.getColumnModel().getColumn(1).setPreferredWidth(15);
        HoodTable.getColumnModel().getColumn(1).setHeaderValue(resourceMap.getString("HoodTable.columnModel.title1")); // NOI18N

        javax.swing.GroupLayout jPanel10Layout = new javax.swing.GroupLayout(jPanel10);
        jPanel10.setLayout(jPanel10Layout);
        jPanel10Layout.setHorizontalGroup(
            jPanel10Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel10Layout.createSequentialGroup()
                .addGap(74, 74, 74)
                .addComponent(jLabel11)
                .addGap(77, 77, 77)
                .addComponent(Next_victim)
                .addContainerGap(435, Short.MAX_VALUE))
            .addGroup(jPanel10Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                .addGroup(jPanel10Layout.createSequentialGroup()
                    .addGap(71, 71, 71)
                    .addComponent(jScrollPane9, javax.swing.GroupLayout.PREFERRED_SIZE, 256, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addContainerGap(395, Short.MAX_VALUE)))
        );
        jPanel10Layout.setVerticalGroup(
            jPanel10Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel10Layout.createSequentialGroup()
                .addGap(325, 325, 325)
                .addGroup(jPanel10Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(jLabel11)
                    .addComponent(Next_victim))
                .addContainerGap(78, Short.MAX_VALUE))
            .addGroup(jPanel10Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                .addGroup(jPanel10Layout.createSequentialGroup()
                    .addGap(21, 21, 21)
                    .addComponent(jScrollPane9, javax.swing.GroupLayout.PREFERRED_SIZE, 296, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addContainerGap(100, Short.MAX_VALUE)))
        );

        jTabbedPane1.addTab(resourceMap.getString("jPanel10.TabConstraints.tabTitle"), jPanel10); // NOI18N

        javax.swing.GroupLayout jPanel6Layout = new javax.swing.GroupLayout(jPanel6);
        jPanel6.setLayout(jPanel6Layout);
        jPanel6Layout.setHorizontalGroup(
            jPanel6Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel6Layout.createSequentialGroup()
                .addGroup(jPanel6Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, jPanel6Layout.createSequentialGroup()
                        .addContainerGap()
                        .addComponent(jPanel8, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
                    .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, jPanel6Layout.createSequentialGroup()
                        .addGap(6, 6, 6)
                        .addComponent(jTabbedPane1, javax.swing.GroupLayout.DEFAULT_SIZE, 727, Short.MAX_VALUE)))
                .addContainerGap())
        );
        jPanel6Layout.setVerticalGroup(
            jPanel6Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel6Layout.createSequentialGroup()
                .addContainerGap()
                .addComponent(jPanel8, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(jTabbedPane1, javax.swing.GroupLayout.PREFERRED_SIZE, 445, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addContainerGap(106, Short.MAX_VALUE))
        );

        jSplitPane2.setLeftComponent(jPanel6);

        jPanel7.setName("jPanel7"); // NOI18N

        jScrollPane6.setName("jScrollPane6"); // NOI18N

        summary_2.setModel(new javax.swing.table.DefaultTableModel(
            new Object [][] {
                {null, null}
            },
            new String [] {
                "Replacement Policy", "Page Level"
            }
        ));
        summary_2.setName("summary_2"); // NOI18N
        jScrollPane6.setViewportView(summary_2);
        summary_2.getColumnModel().getColumn(1).setHeaderValue(resourceMap.getString("summary_2.columnModel.title1")); // NOI18N

        jScrollPane7.setName("jScrollPane7"); // NOI18N

        summary.setModel(new javax.swing.table.DefaultTableModel(
            new Object [][] {
                {null, null, null}
            },
            new String [] {
                "virtual memory", "main memory", "page size"
            }
        ));
        summary.setName("summary"); // NOI18N
        jScrollPane7.setViewportView(summary);
        summary.getColumnModel().getColumn(0).setHeaderValue(resourceMap.getString("summary.columnModel.title0")); // NOI18N
        summary.getColumnModel().getColumn(2).setHeaderValue(resourceMap.getString("summary.columnModel.title2")); // NOI18N

        jScrollPane1.setName("jScrollPane1"); // NOI18N

        HistoryBox.setBackground(resourceMap.getColor("HistoryBox.background")); // NOI18N
        HistoryBox.setColumns(20);
        HistoryBox.setRows(5);
        HistoryBox.setBorder(javax.swing.BorderFactory.createTitledBorder(null, resourceMap.getString("HistoryBox.border.title"), javax.swing.border.TitledBorder.DEFAULT_JUSTIFICATION, javax.swing.border.TitledBorder.DEFAULT_POSITION, new java.awt.Font("Tahoma", 0, 11), resourceMap.getColor("HistoryBox.border.titleColor"))); // NOI18N
        HistoryBox.setName("HistoryBox"); // NOI18N
        jScrollPane1.setViewportView(HistoryBox);

        javax.swing.GroupLayout jPanel7Layout = new javax.swing.GroupLayout(jPanel7);
        jPanel7.setLayout(jPanel7Layout);
        jPanel7Layout.setHorizontalGroup(
            jPanel7Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel7Layout.createSequentialGroup()
                .addGroup(jPanel7Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(jPanel7Layout.createSequentialGroup()
                        .addGap(33, 33, 33)
                        .addComponent(jScrollPane1, javax.swing.GroupLayout.DEFAULT_SIZE, 254, Short.MAX_VALUE))
                    .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, jPanel7Layout.createSequentialGroup()
                        .addContainerGap(33, Short.MAX_VALUE)
                        .addComponent(jScrollPane6, javax.swing.GroupLayout.PREFERRED_SIZE, 254, javax.swing.GroupLayout.PREFERRED_SIZE)))
                .addContainerGap())
            .addGroup(jPanel7Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, jPanel7Layout.createSequentialGroup()
                    .addContainerGap(29, Short.MAX_VALUE)
                    .addComponent(jScrollPane7, javax.swing.GroupLayout.PREFERRED_SIZE, 254, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addGap(14, 14, 14)))
        );
        jPanel7Layout.setVerticalGroup(
            jPanel7Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel7Layout.createSequentialGroup()
                .addGap(106, 106, 106)
                .addComponent(jScrollPane6, javax.swing.GroupLayout.PREFERRED_SIZE, 50, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addGap(36, 36, 36)
                .addComponent(jScrollPane1, javax.swing.GroupLayout.PREFERRED_SIZE, 329, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addContainerGap(197, Short.MAX_VALUE))
            .addGroup(jPanel7Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                .addGroup(jPanel7Layout.createSequentialGroup()
                    .addGap(21, 21, 21)
                    .addComponent(jScrollPane7, javax.swing.GroupLayout.PREFERRED_SIZE, 50, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addContainerGap(647, Short.MAX_VALUE)))
        );

        jSplitPane2.setRightComponent(jPanel7);

        javax.swing.GroupLayout jPanel5Layout = new javax.swing.GroupLayout(jPanel5);
        jPanel5.setLayout(jPanel5Layout);
        jPanel5Layout.setHorizontalGroup(
            jPanel5Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addComponent(jSplitPane2, javax.swing.GroupLayout.DEFAULT_SIZE, 1043, Short.MAX_VALUE)
        );
        jPanel5Layout.setVerticalGroup(
            jPanel5Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel5Layout.createSequentialGroup()
                .addContainerGap()
                .addComponent(jSplitPane2, javax.swing.GroupLayout.PREFERRED_SIZE, 720, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
        );

        jSplitPane1.setRightComponent(jPanel5);

        javax.swing.GroupLayout mainPanelLayout = new javax.swing.GroupLayout(mainPanel);
        mainPanel.setLayout(mainPanelLayout);
        mainPanelLayout.setHorizontalGroup(
            mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(mainPanelLayout.createSequentialGroup()
                .addContainerGap()
                .addComponent(jSplitPane1, javax.swing.GroupLayout.DEFAULT_SIZE, 1249, Short.MAX_VALUE)
                .addContainerGap())
        );
        mainPanelLayout.setVerticalGroup(
            mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(mainPanelLayout.createSequentialGroup()
                .addContainerGap()
                .addComponent(jSplitPane1, javax.swing.GroupLayout.PREFERRED_SIZE, 639, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addContainerGap(21, Short.MAX_VALUE))
        );

        menuBar.setName("menuBar"); // NOI18N

        fileMenu.setText(resourceMap.getString("fileMenu.text")); // NOI18N
        fileMenu.setName("fileMenu"); // NOI18N

        javax.swing.ActionMap actionMap = org.jdesktop.application.Application.getInstance(learningtool.LearningToolApp.class).getContext().getActionMap(LearningToolView.class, this);
        exitMenuItem.setAction(actionMap.get("quit")); // NOI18N
        exitMenuItem.setName("exitMenuItem"); // NOI18N
        fileMenu.add(exitMenuItem);

        menuBar.add(fileMenu);

        helpMenu.setText(resourceMap.getString("helpMenu.text")); // NOI18N
        helpMenu.setName("helpMenu"); // NOI18N

        aboutMenuItem.setAction(actionMap.get("showAboutBox")); // NOI18N
        aboutMenuItem.setName("aboutMenuItem"); // NOI18N
        helpMenu.add(aboutMenuItem);

        menuBar.add(helpMenu);

        statusPanel.setName("statusPanel"); // NOI18N

        statusPanelSeparator.setName("statusPanelSeparator"); // NOI18N

        statusMessageLabel.setName("statusMessageLabel"); // NOI18N

        statusAnimationLabel.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
        statusAnimationLabel.setName("statusAnimationLabel"); // NOI18N

        progressBar.setName("progressBar"); // NOI18N

        javax.swing.GroupLayout statusPanelLayout = new javax.swing.GroupLayout(statusPanel);
        statusPanel.setLayout(statusPanelLayout);
        statusPanelLayout.setHorizontalGroup(
            statusPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addComponent(statusPanelSeparator, javax.swing.GroupLayout.DEFAULT_SIZE, 1269, Short.MAX_VALUE)
            .addGroup(statusPanelLayout.createSequentialGroup()
                .addContainerGap()
                .addComponent(statusMessageLabel)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, 1099, Short.MAX_VALUE)
                .addComponent(progressBar, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(statusAnimationLabel)
                .addContainerGap())
        );
        statusPanelLayout.setVerticalGroup(
            statusPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(statusPanelLayout.createSequentialGroup()
                .addComponent(statusPanelSeparator, javax.swing.GroupLayout.PREFERRED_SIZE, 2, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                .addGroup(statusPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(statusMessageLabel)
                    .addComponent(statusAnimationLabel)
                    .addComponent(progressBar, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addGap(3, 3, 3))
        );

        setComponent(mainPanel);
        setMenuBar(menuBar);
        setStatusBar(statusPanel);
    }// </editor-fold>//GEN-END:initComponents

    private void SubmitActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_SubmitActionPerformed
        // TODO add your handling code here:
        jSplitPane1.setDividerLocation(0);
       
        //input.getPsz();
        //input.setVM_MM();
        input.getPsz();
        input.getVM();
        input.getMM();
        ButtonModel rp = buttonGroup1.getSelection(); //For Selecting the replacement policy.
        String Rpolicy = rp.getActionCommand();
        if(Rpolicy.equals("MORE..."))
        {
            input.getPolicy();
        }
        else
        {
            InputParameter.RPolicy = Rpolicy;
        }
        rp = buttonGroup2.getSelection();
        String Plevel = rp.getActionCommand();
        InputParameter.PageLevel = Plevel;
        input.setPages(0,Color.ORANGE);
        summary.setValueAt("   "+InputParameter.VM+" KB", 0, 0);
        summary.setValueAt("   "+InputParameter.PageLevel,0, 1);
        summary.setValueAt("   "+InputParameter.PSz+" KB", 0, 2);
        summary_2.setValueAt("        "+InputParameter.RPolicy, 0, 0);
        summary_2.setValueAt("     "+InputParameter.PageLevel, 0, 1);
         if(InputParameter.PageLevel.equals("TWO LEVEL"))
            jSplitPane3.setDividerLocation(0);
        else
            jSplitPane3.setDividerLocation(1000);

        VM_Table.setBackground(Color.yellow);
        MM_Table.setBackground(Color.yellow);
        fifo.initialize();
        VM_Table.setVisible(true);
        /*
         * constraints for two level page
         * 1) 
         */
    }//GEN-LAST:event_SubmitActionPerformed

    private void RestartActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_RestartActionPerformed
        // TODO add your handling code here:
        jSplitPane1.setDividerLocation(200);
        jSplitPane3.setDividerLocation(0);
        Policy.RestartFunction();
        // jSplitPane2.setDividerLocation(850);

    }//GEN-LAST:event_RestartActionPerformed

    private void MoreActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_MoreActionPerformed
        // TODO add your handling code here:
        Extra_Policy.setVisible(true);
        Fifo.setVisible(false);
        Lru.setVisible(false);
        Lifo.setVisible(false);
       

    }//GEN-LAST:event_MoreActionPerformed

    private void PS_ComboActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_PS_ComboActionPerformed
        // TODO add your handling code here:
        input.getPsz();
        input.setVM_MM();
    }//GEN-LAST:event_PS_ComboActionPerformed

    private void Generate_VAActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_Generate_VAActionPerformed
        //VM_renderer = new TableColor(1,Color.red);
        //VM_Table.setDefaultRenderer(Object.class,VM_renderer);
        VA_Generator(0);

    }


    public void VA_Generator(int button)    // button is for identifying which of the four button is prssed for generating the address.
    {
         ButtonModel rw = buttonGroup3.getSelection(); //For Selecting the replacement policy.
         String read_write = rw.getActionCommand();

         int VA_input=-1;
         int input_add=-1;

         if(button==1 )  //manual button for VA
            {
                
                try
                {
                     input_add = Integer.valueOf(VA_Generate.getText().trim(),16).intValue();
                     
                }
                catch(Exception e)
                {
                    Policy.GiveExplaination("Only Enter  Hexadecimal Address");
                    return;
                }
                if(input_add > InputParameter.VM*1024-1)
                {
                    Policy.GiveExplaination("Enter Address in limit ("+Integer.toHexString(InputParameter.VM*1024-1)+")");
                    return;
                }
                else
                {

                    VA_input = input_add;
                }
            }

     
      int victim=0;
      if(InputParameter.RPolicy.equals("FIFO"))
      {
        fifo.SplitAddr(button, VA_input);




        //####################################################################
        VM_Table.setRowSelectionInterval(FIFO.VPN,FIFO.VPN);
        VM_Table.setSelectionBackground(Color.black);
        int phit=fifo.pagehit();
       int isvPagedirty=0;
        if(phit>=0)
        {
           PageHit++;
           MM_Table.setRowSelectionInterval(phit,phit);
           MM_Table.setSelectionBackground(Color.green);
//           fifo.Update_PTable();
           NumHit.setText(Integer.toString(PageHit));
           fifo.updateHistoryBox("  VPG - "+FIFO.VPN+" PAGE HIT"+'\n');
           if(read_write.equals("WRITE"))
           {
             Policy.Read[phit]=1;
           }
           else
               Policy.Read[phit]=0;

           fifo.setPTE(FIFO.VPN,phit,Color.GREEN);
           fifo.GiveExplaination("$ HEY! IT'S A PAGE HIT OUR VIRTUAL PAGE("+fifo.VPN+") MAPS"+"\n"+" TO PHYSICAL PAGE ("+fifo.VM_pages[fifo.VPN]+").");
        }
        else//pagefault
        {
           boolean IsMMempty = fifo.IsMainMemoryEmpty();
           PageMiss++;
           victim = fifo.getVictimPage();
           MM_Table.setRowSelectionInterval(victim,victim);
           MM_Table.setSelectionBackground(Color.red);

           NumMiss.setText(Integer.toString(PageMiss));
           fifo.updateHistoryBox("  VPG - "+FIFO.VPN+" PAGE FAULT"+'\n');
           isvPagedirty = Policy.Read[victim];
           if(read_write.equals("WRITE"))
           {
             Policy.Read[victim]=1;
           }
           else
                Policy.Read[victim]=0;

           fifo.setPTE(FIFO.VPN,victim,Color.RED);
        
         fifo.setDirty();

        fifo.setUnderTheHood();
        if(IsMMempty)
        {
            fifo.GiveExplaination("$  PAGE FAULT OCCURS BUT OUR PHYSICAL PAGES ARE EMPTY.\nSO WE DON'T NEED TO FIND ANY VICTIM PAGE FROM\nPHYSICAL MEMORY.");
        }
        else
        {
          if(isvPagedirty==0)
               fifo.GiveExplaination("$ PAGE FAULT OCCURS BUT OUR PHYSICAL MEMORY IS FULL"+"\n"+" NOW.SO WE HAVE TO"
                + " FIND AN VICTIM PAGE FROM PHYSICAL"+"\n"+" MEMORY TO REPLACE IT WITH OUR CURRENT VIRTUAL"+"\n"+"PAGE("+fifo.VPN+")."
                + "NOW TO FIND VICTIM PAGE WE APPLY OUR PAGE"+"\n"+" REPLACEMENT POLICY THIS TIME IT IS FIFO. BY THIS"+"\n"
                + " POLICY VICTIM PAGE FOUND IS "+victim+" WHICH IS NOT DIRTY."+"\n"+"SO WE DON'T REQUIRE TO COPY IT BACK ON DISK."
                + " NOW"+"\n"+" IT'S OVER, WE JUST HAVE TO REPLACE THIS VICTIM PAGE"+"\n"+" WITH OUR VIRTUAL PAGE." );
          else
               fifo.GiveExplaination("$ PAGE FAULT OCCURS BUT OUR PHYSICAL MEMORY IS FULL"+"\n"+" NOW.SO WE HAVE TO"
                + " FIND AN VICTIM PAGE FROM PHYSICAL"+"\n"+" MEMORY TO REPLACE IT WITH OUR CURRENT VIRTUAL"+"\n"+"PAGE("+fifo.VPN+")."
                + "NOW TO FIND VICTIM PAGE WE APPLY OUR PAGE"+"\n"+" REPLACEMENT POLICY THIS TIME IT IS FIFO. BY THIS"+"\n"
                + " POLICY VICTIM PAGE FOUND IS "+victim+" WHICH IS DIRTY."+"\n"+"SO WE REQUIRE TO COPY IT BACK ON DISK."
                + " NOW"+"\n"+" IT'S OVER, WE JUST HAVE TO REPLACE THIS VICTIM PAGE"+"\n"+" WITH OUR VIRTUAL PAGE." );



          }
          }

      }
       
    }//GEN-LAST:event_Generate_VAActionPerformed

    private void MAP_VA_button1(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_MAP_VA_button1
        VA_Generator(1);
    }//GEN-LAST:event_MAP_VA_button1

    private void VPN_Box_button3(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_VPN_Box_button3
        VA_Generator(3);
    }//GEN-LAST:event_VPN_Box_button3

    private void VPN_Box_Button2(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_VPN_Box_Button2
        VA_Generator(2);
    }//GEN-LAST:event_VPN_Box_Button2

    // Variables declaration - do not modify//GEN-BEGIN:variables
    public static javax.swing.JTable AddressDetail1;
    public static javax.swing.JTable AddressDetail2;
    public static javax.swing.JTextArea Explaination;
    public static javax.swing.JComboBox Extra_Policy;
    public static javax.swing.JRadioButton Fifo;
    private javax.swing.JButton Generate_VA;
    private javax.swing.JButton Generate_VPN;
    public static javax.swing.JTextArea HistoryBox;
    public static javax.swing.JTable HoodTable;
    public static javax.swing.JTable Level1;
    public static javax.swing.JTable Level2;
    public static javax.swing.JRadioButton Lifo;
    public static javax.swing.JRadioButton Lru;
    public static javax.swing.JComboBox MM_Combo;
    public static javax.swing.JTable MM_Table;
    private javax.swing.JButton Map_VA;
    private javax.swing.JButton Map_VPN;
    private javax.swing.JRadioButton More;
    public static javax.swing.JLabel Next_victim;
    public static javax.swing.JLabel NumHit;
    public static javax.swing.JLabel NumMiss;
    private javax.swing.JRadioButton One_level;
    public static javax.swing.JComboBox PS_Combo;
    private javax.swing.JButton Restart;
    private javax.swing.JButton Submit;
    private javax.swing.JComboBox TLB_Combo;
    private javax.swing.JRadioButton Two_Level;
    public static javax.swing.JTextField VA_Generate;
    public static javax.swing.JComboBox VM_Combo;
    public static javax.swing.JTable VM_Table;
    public static javax.swing.JTextField VPN_Box;
    private javax.swing.ButtonGroup buttonGroup1;
    private javax.swing.ButtonGroup buttonGroup2;
    private javax.swing.ButtonGroup buttonGroup3;
    private javax.swing.JLabel jLabel1;
    private javax.swing.JLabel jLabel11;
    private javax.swing.JLabel jLabel2;
    private javax.swing.JLabel jLabel3;
    private javax.swing.JLabel jLabel4;
    private javax.swing.JLabel jLabel5;
    private javax.swing.JLabel jLabel6;
    private javax.swing.JLabel jLabel7;
    private javax.swing.JLabel jLabel8;
    private javax.swing.JPanel jPanel1;
    private javax.swing.JPanel jPanel10;
    private javax.swing.JPanel jPanel11;
    private javax.swing.JPanel jPanel12;
    private javax.swing.JPanel jPanel13;
    private javax.swing.JPanel jPanel14;
    private javax.swing.JPanel jPanel2;
    private javax.swing.JPanel jPanel3;
    private javax.swing.JPanel jPanel4;
    private javax.swing.JPanel jPanel5;
    private javax.swing.JPanel jPanel6;
    private javax.swing.JPanel jPanel7;
    private javax.swing.JPanel jPanel8;
    private javax.swing.JPanel jPanel9;
    private javax.swing.JRadioButton jRadioButton7;
    private javax.swing.JRadioButton jRadioButton8;
    private javax.swing.JScrollPane jScrollPane1;
    private javax.swing.JScrollPane jScrollPane10;
    private javax.swing.JScrollPane jScrollPane11;
    private javax.swing.JScrollPane jScrollPane2;
    private javax.swing.JScrollPane jScrollPane3;
    private javax.swing.JScrollPane jScrollPane4;
    private javax.swing.JScrollPane jScrollPane5;
    private javax.swing.JScrollPane jScrollPane6;
    private javax.swing.JScrollPane jScrollPane7;
    private javax.swing.JScrollPane jScrollPane8;
    private javax.swing.JScrollPane jScrollPane9;
    private javax.swing.JSplitPane jSplitPane1;
    private javax.swing.JSplitPane jSplitPane2;
    private javax.swing.JSplitPane jSplitPane3;
    public static javax.swing.JSplitPane jSplitPane4;
    private javax.swing.JTabbedPane jTabbedPane1;
    private javax.swing.JPanel mainPanel;
    private javax.swing.JMenuBar menuBar;
    private javax.swing.JProgressBar progressBar;
    private javax.swing.JLabel statusAnimationLabel;
    private javax.swing.JLabel statusMessageLabel;
    private javax.swing.JPanel statusPanel;
    public static javax.swing.JTable summary;
    public static javax.swing.JTable summary_2;
    // End of variables declaration//GEN-END:variables
    private final Timer messageTimer;
    private final Timer busyIconTimer;
    private final Icon idleIcon;
    private final Icon[] busyIcons = new Icon[15];
    private int busyIconIndex = 0;
    public static InputParameter input = new InputParameter();
    private JDialog aboutBox;
    public static TableCellRenderer VM_renderer = new TableColor(0,Color.yellow);
    private static int start=0;
    Policy lifo = new LIFO();
    Policy fifo = new FIFO();
    public static int va;
    public int cn=0;
    public static int PageHit=0;
    public static int PageMiss=0;
    
}
